@@ -350,3 +350,15 @@ EventDTO = Union[AccountClosedEvent, AccountFrozenEvent, ApplicationDeniedEvent,
                  CheckDepositReturnedEvent, CustomerCreatedEvent, PaymentClearingEvent, PaymentSentEvent,
                  PaymentReturnedEvent, StatementsCreatedEvent, TransactionCreatedEvent, AccountReopenedEvent]
 
+
+class ListEventParams(UnitParams):
+    def __init__(self, limit: int = 100, offset: int = 0, type: Optional[List[str]] = None):
+        self.limit = limit
+        self.offset = offset
+        self.type = type
+
+    def to_dict(self) -> Dict:
+        parameters = {"page[limit]": self.limit, "page[offset]": self.offset}
+        if self.type:
+            parameters["filter[type][]"] = self.type
+        return parameters
